<p align="left">
  <img alt="Scikit Discovery" src="https://github.com/MITHaystack/scikit-discovery/raw/master/skdiscovery/docs/images/skdiscovery_logo360x100.png"/>
</p>

- Explore scientific data with a set of tools for human-guided or automated discovery
- Design & configure data processing pipelines
- Define the parameter ranges for your algorithms, available algorithmic choices, and the framework will generate pipeline instances for you 
- Use automatically perturbed data processing pipelines to create different data products.
- Easy to use with [scikit-dataaccess](https://github.com/MITHaystack/scikit-dataaccess) for integration of a variety of scientific data sets


<p align="center">
  <img alt="Scikit Discovery Overview" src="https://github.com/MITHaystack/scikit-discovery/raw/master/skdiscovery/docs/images/skdiscovery_overviewdiag.png"/>
</p>

### Install
```
pip install scikit-discovery
```

### Documentation

See <https://github.com/MITHaystack/scikit-discovery/tree/master/skdiscovery/docs>

### Contributors

Project lead: [Victor Pankratius (MIT)](http://www.victorpankratius.com)<br>
Contributors: Cody M. Rude, Justin D. Li, David M. Blair, Michael G. Gowanlock, Evan Wojciechowski, Victor Pankratius

### Acknowledgements

We acknowledge support from NASA AIST14-NNX15AG84G, NASA AIST16-80NSSC17K0125, NSF ACI-1442997, NSF AGS-1343967, and Amazon AWS computing access support.

## Examples

Example code with complete science case studies are available as Jupyter Notebooks at: 

[/MITHaystack/science-casestudies](https://github.com/MITHaystack/science-casestudies)
